@@ -1,6 +1,6 @@
 package HTML::Parser;
 
-# Copyright 1996-2003, Gisle Aas.
+# Copyright 1996-2004, Gisle Aas.
 # Copyright 1999-2000, Michael A. Chase.
 #
 # This library is free software; you can redistribute it and/or
@@ -9,7 +9,7 @@ package HTML::Parser;
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = '3.35';  # $Date: 2003/12/12 14:23:16 $
+$VERSION = '3.37';  # $Date: 2004/11/10 18:50:31 $
 
 require HTML::Entities;
 
@@ -159,31 +159,6 @@ HTML::Parser - HTML parser class
  open(F, "foo.html") || die;
  $p->parse_file(*F);
 
-HTML::Parser version 2 style subclassing and method callbacks:
-
- {
-    package MyParser;
-    use base 'HTML::Parser';
-
-    sub start {
-       my($self, $tagname, $attr, $attrseq, $origtext) = @_;
-       #...
-    }
-
-    sub end {
-	my($self, $tagname, $origtext) = @_;
-	#...
-    }
-
-    sub text {
-	my($self, $origtext, $is_cdata) = @_;
-	#...
-    }
- }
-
- my $p = MyParser->new;
- $p->parse_file("foo.html");
-
 =head1 DESCRIPTION
 
 Objects of the C<HTML::Parser> class will recognize markup and
@@ -1132,7 +1107,7 @@ be found at C<http://www.sgml.u-net.com/book/sgml-8.htm>.
 
 =head1 COPYRIGHT
 
- Copyright 1996-2003 Gisle Aas. All rights reserved.
+ Copyright 1996-2004 Gisle Aas. All rights reserved.
  Copyright 1999-2000 Michael A. Chase.  All rights reserved.
 
 This library is free software; you can redistribute it and/or
